@@ -1,6 +1,6 @@
 //===----------------------------------------------------------------------===//
 //
-// Copyright (c) 2012, 2013 The University of Utah
+// Copyright (c) 2012, 2013, 2015 The University of Utah
 // All rights reserved.
 //
 // This file is distributed under the University of Illinois Open Source
@@ -71,7 +71,8 @@ bool RemoveCtorInitializerASTVisitor::VisitCXXConstructorDecl(
     }
     else if (const Type *Ty = Init->getBaseClass()) {
       const CXXRecordDecl *Base = ConsumerInstance->getBaseDeclFromType(Ty);
-      if (Base && Base->needsImplicitDefaultConstructor()) {
+      if (Base && Base->hasDefinition() && 
+          Base->needsImplicitDefaultConstructor()) {
         Idx++;
         continue;
       }
@@ -98,7 +99,8 @@ void RemoveCtorInitializer::Initialize(ASTContext &context)
 
 void RemoveCtorInitializer::HandleTranslationUnit(ASTContext &Ctx)
 {
-  if (TransformationManager::isCLangOpt()) {
+  if (TransformationManager::isCLangOpt() ||
+      TransformationManager::isOpenCLLangOpt()) {
     ValidInstanceNum = 0;
   }
   else {
