@@ -1,6 +1,6 @@
 //===----------------------------------------------------------------------===//
 //
-// Copyright (c) 2012 The University of Utah
+// Copyright (c) 2012, 2013, 2015 The University of Utah
 // All rights reserved.
 //
 // This file is distributed under the University of Illinois Open Source
@@ -16,6 +16,7 @@
 
 #include "clang/Basic/SourceManager.h"
 #include "clang/AST/RecursiveASTVisitor.h"
+#include "clang/AST/ASTContext.h"
 #include "TransformationManager.h"
 
 using namespace clang;
@@ -83,7 +84,8 @@ void RemoveUnresolvedBase::Initialize(ASTContext &context)
 
 void RemoveUnresolvedBase::HandleTranslationUnit(ASTContext &Ctx)
 {
-  if (TransformationManager::isCLangOpt()) {
+  if (TransformationManager::isCLangOpt() ||
+      TransformationManager::isOpenCLLangOpt()) {
     ValidInstanceNum = 0;
   }
   else {
@@ -140,7 +142,6 @@ void RemoveUnresolvedBase::removeBaseSpecifier(void)
 
 RemoveUnresolvedBase::~RemoveUnresolvedBase(void)
 {
-  if (CollectionVisitor)
-    delete CollectionVisitor;
+  delete CollectionVisitor;
 }
 
