@@ -240,6 +240,7 @@ bool RUFAnalysisVisitor::VisitFunctionDecl(FunctionDecl *FD)
 
   if (FD->isReferenced() || 
       FD->isMain() || 
+      FD->hasAttr<OpenCLKernelAttr>() ||
       ConsumerInstance->hasReferencedSpecialization(CanonicalFD) ||
       ConsumerInstance->isInlinedSystemFunction(CanonicalFD) ||
       ConsumerInstance->isInReferencedSet(CanonicalFD) ||
@@ -423,8 +424,16 @@ SourceLocation RemoveUnusedFunction::getFunctionLocEnd(
                  SourceLocation LocEnd,
                  const FunctionDecl *FD)
 {
-  if (!FD->getDescribedFunctionTemplate())
-    return LocEnd;
+  if (!FD->getDescribedFunctionTemplate()) {
+    // Remove trailing ; if function has no body
+    if (!FD->hasBody()) {
+      return RewriteHelper->getLocationUntil(LocEnd, ';');
+    }
+    else {
+      return LocEnd;
+    }
+  }
+
   SourceLocation FDLoc = FD->getLocation();
   const char * const FDBuf = SrcManager->getCharacterData(FDLoc);
   const char * LocEndBuf = SrcManager->getCharacterData(LocEnd);
@@ -639,8 +648,8 @@ RemoveUnusedFunction::lookupFunctionDeclShallow(const DeclarationName &DName,
 {
   if (dyn_cast<LinkageSpecDecl>(Ctx))
     return NULL;
-  DeclContext::lookup_const_result Result = Ctx->lookup(DName);
-  for (DeclContext::lookup_const_iterator I = Result.begin(), E = Result.end();
+  DeclContext::lookup_result Result = Ctx->lookup(DName);
+  for (auto I = Result.begin(), E = Result.end();
        I != E; ++I) {
     if (const FunctionDecl *FD = dyn_cast<FunctionDecl>(*I))
       return FD;
