@@ -1,6 +1,6 @@
 //===----------------------------------------------------------------------===//
 //
-// Copyright (c) 2012 The University of Utah
+// Copyright (c) 2012, 2013, 2015 The University of Utah
 // All rights reserved.
 //
 // This file is distributed under the University of Illinois Open Source
@@ -15,6 +15,7 @@
 #include "RemoveUnusedStructField.h"
 
 #include "clang/AST/RecursiveASTVisitor.h"
+#include "clang/AST/ASTContext.h"
 #include "clang/Basic/SourceManager.h"
 
 #include "TransformationManager.h"
@@ -290,15 +291,23 @@ void RemoveUnusedStructField::getInitExprs(const Type *Ty,
 void RemoveUnusedStructField::removeOneInitExpr(const Expr *E)
 {
   TransAssert(NumFields && "NumFields cannot be zero!");
-  if (NumFields == 1) {
-    RewriteHelper->replaceExpr(E, "");
-    return;
-  }
 
   SourceRange ExpRange = E->getSourceRange();
   SourceLocation StartLoc = ExpRange.getBegin();
   SourceLocation EndLoc = ExpRange.getEnd();
-  if (IsFirstField) {
+
+  if (NumFields == 1) {
+    // The last field can optionally have a trailing comma
+    // If this is the only field also the comma has to be removed
+    SourceLocation NewEndLoc =
+      RewriteHelper->getEndLocationUntil(ExpRange, '}');
+    NewEndLoc = NewEndLoc.getLocWithOffset(-1);
+
+    TheRewriter.RemoveText(SourceRange(StartLoc, NewEndLoc));
+
+    return;
+  }
+  else if (IsFirstField) {
     EndLoc = RewriteHelper->getEndLocationUntil(ExpRange, ',');
     TheRewriter.RemoveText(SourceRange(StartLoc, EndLoc));
     return;
@@ -348,10 +357,8 @@ void RemoveUnusedStructField::removeFieldDecl(void)
 
 RemoveUnusedStructField::~RemoveUnusedStructField(void)
 {
-  if (CollectionVisitor)
-    delete CollectionVisitor;
-  if (RewriteVisitor)
-    delete RewriteVisitor;
+  delete CollectionVisitor;
+  delete RewriteVisitor;
 
   for (RecordDeclToFieldIdxVectorMap::iterator I = RecordDeclToField.begin(),
        E = RecordDeclToField.end(); I != E; ++I) {
