@@ -1,6 +1,6 @@
 //===----------------------------------------------------------------------===//
 //
-// Copyright (c) 2012, 2013 The University of Utah
+// Copyright (c) 2012, 2013, 2015 The University of Utah
 // All rights reserved.
 //
 // This file is distributed under the University of Illinois Open Source
@@ -73,7 +73,8 @@ void ReplaceDerivedClass::Initialize(ASTContext &context)
 
 void ReplaceDerivedClass::HandleTranslationUnit(ASTContext &Ctx)
 {
-  if (TransformationManager::isCLangOpt()) {
+  if (TransformationManager::isCLangOpt() ||
+      TransformationManager::isOpenCLLangOpt()) {
     ValidInstanceNum = 0;
   }
   else {
@@ -115,8 +116,8 @@ bool ReplaceDerivedClass::isValidBaseDerivedPair(const CXXRecordDecl *Base,
     return true;
   }
   else if (BaseTmplD && DerivedTmplD) {
-    return (BaseTmplD->getTemplateParameters()->getMinRequiredArguments() ==
-            DerivedTmplD->getTemplateParameters()->getMinRequiredArguments());
+     return (BaseTmplD->getTemplateParameters()->getMinRequiredArguments() ==
+             DerivedTmplD->getTemplateParameters()->getMinRequiredArguments());
   }
 
   return false;
@@ -142,6 +143,8 @@ void ReplaceDerivedClass::handleOneCXXRecordDecl(const CXXRecordDecl *CXXRD)
   if (!CXXDef)
     return;
 
+  if (dyn_cast<ClassTemplateSpecializationDecl>(CXXRD))
+    return;
   if ((CXXDef->getNumBases() == 0) || !isEmptyClass(CXXDef))
     return;
 
