@@ -1,6 +1,6 @@
 //===----------------------------------------------------------------------===//
 //
-// Copyright (c) 2012, 2013 The University of Utah
+// Copyright (c) 2012, 2013, 2015 The University of Utah
 // All rights reserved.
 //
 // This file is distributed under the University of Illinois Open Source
@@ -190,6 +190,9 @@ public:
   bool getFunctionDeclStrAndRemove(const clang::FunctionDecl *FD,
                                    std::string &Str);
 
+  bool replaceFunctionDefWithStr(const clang::FunctionDecl *FD,
+                                 const std::string &Str);
+
   clang::SourceLocation getEndLocationUntil(clang::SourceRange Range,
                                             char Symbol);
 
@@ -223,6 +226,9 @@ public:
   bool removeTextFromLeftAt(clang::SourceRange Range, char C,
                             clang::SourceLocation EndLoc);
 
+  clang::SourceLocation getLocationFromLeftUntil(clang::SourceLocation StartLoc,
+                                                 char C);
+
   bool removeTextUntil(clang::SourceRange Range, char C);
 
   bool replaceCXXDestructorDeclName(const clang::CXXDestructorDecl *DtorDecl, 
@@ -300,6 +306,10 @@ private:
 
   unsigned getNumArgsWrapper(const clang::Expr *E);
 
+  clang::SourceLocation getExpansionEndLoc(clang::SourceLocation EndLoc);
+
+  clang::SourceLocation getMacroExpansionLoc(clang::SourceLocation Loc);
+
   // Unimplemented
   RewriteUtils(const RewriteUtils &);
 
