@@ -1,6 +1,6 @@
 ## -*- mode: Perl -*-
 ##
-## Copyright (c) 2012, 2013 The University of Utah
+## Copyright (c) 2012, 2013, 2015 The University of Utah
 ## All rights reserved.
 ##
 ## This file is distributed under the University of Illinois Open Source
@@ -38,7 +38,7 @@ sub do_transform($$) {
     my ($cfile, $pattern) = @_;
 
     open INF, "<$cfile" or die;
-    my $tmpfile = POSIX::tmpnam();
+    my $tmpfile = File::Temp::tmpnam();
     open OUTF, ">$tmpfile" or die;
 
     my $matched;
@@ -52,7 +52,11 @@ sub do_transform($$) {
 
     close INF;
     close OUTF;
-    move($tmpfile, $cfile) if $matched;
+    if ($matched) {
+        File::Copy::move($tmpfile, $cfile);
+    } else {
+        unlink $tmpfile;
+    }
     return $matched;
 }
 
