@@ -1,6 +1,6 @@
 ## -*- mode: Perl -*-
 ##
-## Copyright (c) 2012, 2013 The University of Utah
+## Copyright (c) 2012, 2013, 2015 The University of Utah
 ## All rights reserved.
 ##
 ## This file is distributed under the University of Illinois Open Source
@@ -15,6 +15,7 @@ use warnings;
 
 use POSIX;
 
+use Cwd 'abs_path';
 use File::Copy;
 use File::Spec;
 
@@ -30,7 +31,7 @@ my $ORIG_DIR;
 sub check_prereqs () {
     $ORIG_DIR = getcwd();
     my $path;
-    if ($FindBin::Bin eq bindir) {
+    if ($FindBin::RealBin eq abs_path(bindir)) {
 	# This script is in the installation directory.
 	# Use the installed `clex'.
 	$path = libexecdir . "/clex";
@@ -43,6 +44,12 @@ sub check_prereqs () {
 	$clex = $path;
 	return 1;
     }
+    # Check Windows
+    $path=$path . ".exe";
+    if (($^O eq "MSWin32") && (-e $path) && (-x $path)) {
+	$clex = $path;
+	return 1;
+    }
     return 0;
 }
 
@@ -61,19 +68,19 @@ sub advance ($$$) {
 sub transform ($$$) {
     (my $cfile, my $which, my $state) = @_;
     my $index = ${$state};
-    my $tmpfile = POSIX::tmpnam();
-    my $cmd = "$clex $which $index $cfile";
+    my $tmpfile = File::Temp::tmpnam();
+    my $cmd = qq{"$clex" $which $index $cfile};
     print "$cmd\n" if $VERBOSE;
     my $res = runit ("$cmd > $tmpfile");
     if ($res==0) {
-	system "mv $tmpfile $cfile";
+	File::Copy::move($tmpfile, $cfile);
 	return ($OK, \$index);
     } else {
 	if ($res == -1) {
 	} else {
 	    # TODO -- log a crash like we do for clang-delta
 	}
-	system "rm $tmpfile";
+	unlink $tmpfile;
 	return ($STOP, \$index);
     }    
 }
