@@ -1,6 +1,6 @@
 ## -*- mode: Perl -*-
 ##
-## Copyright (c) 2012, 2013 The University of Utah
+## Copyright (c) 2012, 2013, 2015 The University of Utah
 ## All rights reserved.
 ##
 ## This file is distributed under the University of Illinois Open Source
@@ -70,9 +70,9 @@ sub transform ($$$) {
     if (defined $sh{"flatten"}) {
 	delete $sh{"flatten"};
 	$sh{"start"} = 1;
-	my $tmpfile = POSIX::tmpnam();
+	my $tmpfile = File::Temp::tmpnam();
 	system "$topformflat $arg < $cfile > $tmpfile";
-	system "mv $tmpfile $cfile";	
+	File::Copy::move($tmpfile, $cfile);
 	print "ran $topformflat $arg < $cfile > $tmpfile\n" if $VERBOSE;
 	return ($OK, \%sh);
     }
@@ -93,7 +93,7 @@ sub transform ($$$) {
 
     my $n=0;
     my $did_something=0;
-    my $tmpfile = POSIX::tmpnam();
+    my $tmpfile = File::Temp::tmpnam();
     open INF, "<$cfile" or die;
     open OUTF, ">$tmpfile" or die;
     while (my $line = <INF>) {
@@ -118,15 +118,16 @@ sub transform ($$$) {
     if ($BACKWARD &&
 	!$did_something &&
 	$sh{"index"} >= 0) {
+    unlink $tmpfile;
 	my $newsh = advance ($cfile, 0, \%sh);
 	%sh = %{$newsh};
 	goto AGAIN;
     }
     
     if ($did_something) {
-	system "mv $tmpfile $cfile";
+	File::Copy::move($tmpfile, $cfile);
     } else {
-	system "rm $tmpfile";
+	unlink $tmpfile;
 	return ($STOP, \%sh) if ($sh{"chunk"} == 1);
 	my $newchunk = round ($sh{"chunk"} / 2.0);
 	$sh{"chunk"} = $newchunk;
